@@ -1,14 +1,16 @@
 import abc
 import textwrap
+import numbers
 
 import numpy as np
+from astropy.time import TimeDelta
+import astropy.units as u
 from ndcube.ndcube import NDCube
 from ndcube.utils.cube import convert_extra_coords_dict_to_input_format
 
-import astropy.units as u
-
 __all__ = ['SpectrogramCube']
 
+
 # Define some custom error messages.
 APPLY_EXPOSURE_TIME_ERROR = ("Exposure time correction has probably already "
                              "been applied since the unit already includes "
@@ -162,14 +164,14 @@ class SpectrogramCube(NDCube, SpectrogramABC):
     """
 
     def __init__(self, data, wcs, extra_coords=None, unit=None, uncertainty=None, meta=None,
-                 mask=None, copy=False, **kwargs):
+                 mask=None, instrument_axes=None, copy=False, **kwargs):
         # Initialize SpectrogramCube.
-        super().__init__(data, wcs, uncertainty=uncertainty, mask=mask, meta=meta, unit=unit,
-                         extra_coords=extra_coords, copy=copy, **kwargs)
+        super().__init__(data, wcs=wcs, uncertainty=uncertainty, mask=mask, meta=meta,
+                         unit=unit, extra_coords=extra_coords, copy=copy, **kwargs)
 
         # Determine labels and location of each key real world coordinate.
         self_extra_coords = self.extra_coords
-        world_axis_physical_types = np.array(self.world_axis_physical_types)
+        world_axis_physical_types = np.array(self.wcs.world_axis_physical_types)
         self._longitude_name, self._longitude_loc = _find_axis_name(
             SUPPORTED_LONGITUDE_NAMES, world_axis_physical_types, self_extra_coords)
         self._latitude_name, self._latitude_loc = _find_axis_name(
@@ -181,12 +183,20 @@ class SpectrogramCube(NDCube, SpectrogramABC):
         self._exposure_time_name, self._exposure_time_loc = _find_axis_name(
             SUPPORTED_EXPOSURE_NAMES, world_axis_physical_types, self_extra_coords)
 
+        # Set up instrument axes if set.
+        if instrument_axes is None:
+            self.instrument_axes = instrument_axes
+        elif len(instrument_axes) != data.ndim:
+            raise ValueError("Length of instrument_axes must match number of data axes.")
+        else:
+            self.instrument_axes = np.asarray(instrument_axes, dtype=str)
+
     def __str__(self):
         if self._time_name:
             if self.time.isscalar:
                 time_period = self.time
             else:
-                time_period = (self.time[0], self.time[-1])
+                time_period = (str(self.time.min()), str(self.time.max()))
         else:
             time_period = None
         if self._longitude_name:
@@ -214,7 +224,8 @@ class SpectrogramCube(NDCube, SpectrogramABC):
                 {self.__class__.__name__}
                 {"".join(["-"] * len(self.__class__.__name__))}
                 Time Period: {time_period}
-                Pixel dimensions (Slit steps, Slit height, Spectral): {self.dimensions}
+                Instrument axes: {self.instrument_axes}
+                Pixel dimensions: {self.dimensions.astype(int)}
                 Longitude range: {lon_range}
                 Latitude range: {lat_range}
                 Spectral range: {spectral_range}
@@ -224,15 +235,41 @@ class SpectrogramCube(NDCube, SpectrogramABC):
         return f"{object.__repr__(self)}\n{str(self)}"
 
     def __getitem__(self, item):
+        # Slice SpectrogramCube using parent slicing.
         result = super().__getitem__(item)
+
+        # As result is an NDCube, must put extra coord back into input format
+        # to create a SpectrogramCube.
         if result.extra_coords is None:
             extra_coords = None
         else:
             extra_coords = convert_extra_coords_dict_to_input_format(result.extra_coords,
                                                                      result.missing_axes)
-        return self.__class__(result.data, result.wcs, extra_coords, result.unit,
-                              result.uncertainty, result.meta, mask=result.mask,
-                              missing_axes=result.missing_axes)
+
+        # Slice instrument_axes if it exists.
+        # If item is a slice, cube dimensionality is not reduced
+        # so instrument_axes need not be sliced.
+        if self.instrument_axes is None or isinstance(item, slice):
+            instrument_axes = self.instrument_axes
+        else:
+            # If item is int, instrument_axes needs slicing.
+            if isinstance(item, numbers.Integral):
+                instrument_axes = self.instrument_axes[1:]
+            # If item is tuple, instrument axes will need to be sliced if tuple contains an int.
+            elif isinstance(item, tuple):
+                instr_item = [isinstance(i, numbers.Integral) for i in item] + \
+                        [False] * (len(self.instrument_axes) - len(item))
+                instrument_axes = self.instrument_axes[np.invert(instr_item)]
+            else:
+                raise TypeError("Unrecognized slice item. Must be int, slice or tuple.")
+            # If slicing causes cube to be a scalar, set instrument_axes to None.
+            if len(instrument_axes) == 0:
+                instrument_axes = None
+
+        return self.__class__(result.data, wcs=result.wcs, uncertainty=result.uncertainty,
+                              mask=result.mask, meta=result.meta, unit=result.unit,
+                              extra_coords=extra_coords, missing_axes=result.missing_axes,
+                              instrument_axes=instrument_axes)
 
     @property
     def spectral_axis(self):
@@ -246,7 +283,14 @@ class SpectrogramCube(NDCube, SpectrogramABC):
         if not self._time_name:
             raise ValueError("Time" + AXIS_NOT_FOUND_ERROR +
                              f"{SUPPORTED_TIME_NAMES}")
-        return self._get_axis_coord(self._time_name, self._time_loc)
+        times = self._get_axis_coord(self._time_name, self._time_loc)
+        if isinstance(times, (u.Quantity, TimeDelta)):
+            try:
+                if self.meta.date_reference:
+                    times += self.meta.date_reference
+            except AttributeError:
+                pass
+        return times
 
     @property
     def exposure_time(self):
@@ -295,7 +339,7 @@ class SpectrogramCube(NDCube, SpectrogramABC):
         # Return new instance of SpectrogramCube with correction applied/undone.
 
         return self.__class__(
-            new_data, self.wcs,
+            new_data, wcs=self.wcs,
             extra_coords=convert_extra_coords_dict_to_input_format(self.extra_coords,
                                                                    self.missing_axes),
             unit=new_unit, uncertainty=new_uncertainty, meta=self.meta, mask=self.mask,
@@ -303,7 +347,7 @@ class SpectrogramCube(NDCube, SpectrogramABC):
 
     def _get_axis_coord(self, axis_name, coord_loc):
         if coord_loc == "wcs":
-            return self.axis_world_coords(axis_name)
+            return self.axis_world_coords_values(axis_name)[0]
         elif coord_loc == "extra_coords":
             return self.extra_coords[axis_name]["value"]
 
